clear
set more off

// Read in CPS data

quietly infix                ///
  int     year      1-4      ///
  long    serial    5-9      ///
  float   hwtsupp   10-19    ///
  byte    statefip  20-21    ///
  byte    asecflag  22-22    ///
  long    stampval  23-27    ///
  float   cpi99     28-31    ///
  byte    month     32-33    ///
  byte    pernum    34-35    ///
  float   wtsupp    36-45    ///
  byte    nchild    46-46    ///
  int     relate    47-50    ///
  byte    age       51-52    ///
  byte    sex       53-53    ///
  int     race      54-56    ///
  byte    marst     57-57    ///
  byte    educ99    58-59    ///
  byte    wkswork1  60-61    ///
  byte    wkswork2  62-62    ///
  byte    hrswork   63-64    ///
  byte    uhrswork  65-66    ///
  byte    wksunem1  67-68    ///
  byte    wksunem2  69-69    ///
  byte    nwlookwk  70-71    ///
  float   hourwage  72-75    ///
  byte    paidhour  76-76    ///
  byte    numemps   77-77    ///
  double  ftotval   78-87    ///
  double  inctot    88-95    ///
  long    incwage   96-102   ///
  long    incbus    103-109  ///
  long    incfarm   110-116  ///
  long    incss     117-121  ///
  long    incwelfr  122-126  ///
  long    incretir  127-132  ///
  long    incssi    133-137  ///
  long    incint    138-142  ///
  long    incunemp  143-147  ///
  long    incdivid  148-153  ///
  long    incrent   154-158  ///
  int     eitcred   159-162  ///
  long    fedtaxac  163-168  ///
  long    fica      169-173  ///
  byte    filestat  174-174  ///
  byte    margtax   175-176  ///
  long    stataxac  177-182  ///
  long    taxinc    183-189  ///
  byte    caid      190-190  ///
  byte    schip     191-191  ///
  byte    ftype     192-192  ///
  using $dropbox/data/input/cps_00012.dat

replace hwtsupp  = hwtsupp  / 10000
replace cpi99    = cpi99    / 1000
replace wtsupp   = wtsupp   / 10000
replace hourwage = hourwage / 100

format hwtsupp  %10.4f
format cpi99    %4.3f
format wtsupp   %10.4f
format hourwage %4.2f
format ftotval  %10.0f
format inctot   %8.0f

label var year     `"Survey year"'
label var serial   `"Household serial number"'
label var hwtsupp  `"Household weight, Supplement"'
label var statefip `"State (FIPS code)"'
label var asecflag `"Flag for ASEC"'
label var stampval `"Total value of food stamps"'
label var cpi99    `"CPI-U adjustment factor to 1999 dollars"'
label var month    `"Month"'
label var pernum   `"Person number in sample unit"'
label var wtsupp   `"Supplement Weight"'
label var nchild   `"Number of own children in household"'
label var relate   `"Relationship to household head"'
label var age      `"Age"'
label var sex      `"Sex"'
label var race     `"Race"'
label var marst    `"Marital status"'
label var educ99   `"Educational attainment, 1990"'
label var wkswork1 `"Weeks worked last year"'
label var wkswork2 `"Weeks worked last year, intervalled"'
label var hrswork  `"Hours worked last week"'
label var uhrswork `"Usual hours worked per week (last yr)"'
label var wksunem1 `"Weeks unemployed last year"'
label var wksunem2 `"Weeks unemployed last year, intervalled"'
label var nwlookwk `"Weeks looked for work last year (didn't work)"'
label var hourwage `"Hourly wage"'
label var paidhour `"Paid by the hour"'
label var numemps  `"Number of employers last year"'
label var ftotval  `"Total family income"'
label var inctot   `"Total personal income"'
label var incwage  `"Wage and salary income"'
label var incbus   `"Non-farm business income"'
label var incfarm  `"Farm income"'
label var incss    `"Social Security income"'
label var incwelfr `"Welfare (public assistance) income"'
label var incretir `"Retirement income"'
label var incssi   `"Income from SSI"'
label var incint   `"Income from interest"'
label var incunemp `"Income from unemployment benefits"'
label var incdivid `"Income from dividends"'
label var incrent  `"Income from rent"'
label var eitcred  `"Earned income tax credit"'
label var fedtaxac `"Federal income tax liability, after all credits"'
label var fica     `"Social security retirement payroll deduction"'
label var filestat `"Tax filer status"'
label var margtax  `"Federal income marginal tax rate"'
label var stataxac `"State income tax liability, after all credits"'
label var taxinc   `"Taxable income amount"'
label var caid     `"Covered by Medicaid last year"'
label var schip    `"State Children's Health Insurance Program coverage last year"'
label var ftype    `"Family Type"'

label define statefip_lbl 01 `"Alabama"'
label define statefip_lbl 02 `"Alaska"', add
label define statefip_lbl 04 `"Arizona"', add
label define statefip_lbl 05 `"Arkansas"', add
label define statefip_lbl 06 `"California"', add
label define statefip_lbl 08 `"Colorado"', add
label define statefip_lbl 09 `"Connecticut"', add
label define statefip_lbl 10 `"Delaware"', add
label define statefip_lbl 11 `"District of Columbia"', add
label define statefip_lbl 12 `"Florida"', add
label define statefip_lbl 13 `"Georgia"', add
label define statefip_lbl 15 `"Hawaii"', add
label define statefip_lbl 16 `"Idaho"', add
label define statefip_lbl 17 `"Illinois"', add
label define statefip_lbl 18 `"Indiana"', add
label define statefip_lbl 19 `"Iowa"', add
label define statefip_lbl 20 `"Kansas"', add
label define statefip_lbl 21 `"Kentucky"', add
label define statefip_lbl 22 `"Louisiana"', add
label define statefip_lbl 23 `"Maine"', add
label define statefip_lbl 24 `"Maryland"', add
label define statefip_lbl 25 `"Massachusetts"', add
label define statefip_lbl 26 `"Michigan"', add
label define statefip_lbl 27 `"Minnesota"', add
label define statefip_lbl 28 `"Mississippi"', add
label define statefip_lbl 29 `"Missouri"', add
label define statefip_lbl 30 `"Montana"', add
label define statefip_lbl 31 `"Nebraska"', add
label define statefip_lbl 32 `"Nevada"', add
label define statefip_lbl 33 `"New Hampshire"', add
label define statefip_lbl 34 `"New Jersey"', add
label define statefip_lbl 35 `"New Mexico"', add
label define statefip_lbl 36 `"New York"', add
label define statefip_lbl 37 `"North Carolina"', add
label define statefip_lbl 38 `"North Dakota"', add
label define statefip_lbl 39 `"Ohio"', add
label define statefip_lbl 40 `"Oklahoma"', add
label define statefip_lbl 41 `"Oregon"', add
label define statefip_lbl 42 `"Pennsylvania"', add
label define statefip_lbl 44 `"Rhode Island"', add
label define statefip_lbl 45 `"South Carolina"', add
label define statefip_lbl 46 `"South Dakota"', add
label define statefip_lbl 47 `"Tennessee"', add
label define statefip_lbl 48 `"Texas"', add
label define statefip_lbl 49 `"Utah"', add
label define statefip_lbl 50 `"Vermont"', add
label define statefip_lbl 51 `"Virginia"', add
label define statefip_lbl 53 `"Washington"', add
label define statefip_lbl 54 `"West Virginia"', add
label define statefip_lbl 55 `"Wisconsin"', add
label define statefip_lbl 56 `"Wyoming"', add
label define statefip_lbl 61 `"Maine-New Hampshire-Vermont"', add
label define statefip_lbl 65 `"Montana-Idaho-Wyoming"', add
label define statefip_lbl 68 `"Alaska-Hawaii"', add
label define statefip_lbl 69 `"Nebraska-North Dakota-South Dakota"', add
label define statefip_lbl 70 `"Maine-Massachusetts-New Hampshire-Rhode Island-Vermont"', add
label define statefip_lbl 71 `"Michigan-Wisconsin"', add
label define statefip_lbl 72 `"Minnesota-Iowa"', add
label define statefip_lbl 73 `"Nebraska-North Dakota-South Dakota-Kansas"', add
label define statefip_lbl 74 `"Delaware-Virginia"', add
label define statefip_lbl 75 `"North Carolina-South Carolina"', add
label define statefip_lbl 76 `"Alabama-Mississippi"', add
label define statefip_lbl 77 `"Arkansas-Oklahoma"', add
label define statefip_lbl 78 `"Arizona-New Mexico-Colorado"', add
label define statefip_lbl 79 `"Idaho-Wyoming-Utah-Montana-Nevada"', add
label define statefip_lbl 80 `"Alaska-Washington-Hawaii"', add
label define statefip_lbl 81 `"New Hampshire-Maine-Vermont-Rhode Island"', add
label define statefip_lbl 83 `"South Carolina-Georgia"', add
label define statefip_lbl 84 `"Kentucky-Tennessee"', add
label define statefip_lbl 85 `"Arkansas-Louisiana-Oklahoma"', add
label define statefip_lbl 87 `"Iowa-N Dakota-S Dakota-Nebraska-Kansas-Minnesota-Missouri"', add
label define statefip_lbl 88 `"Washington-Oregon-Alaska-Hawaii"', add
label define statefip_lbl 89 `"Montana-Wyoming-Colorado-New Mexico-Utah-Nevada-Arizona"', add
label define statefip_lbl 90 `"Delaware-Maryland-Virginia-West Virginia"', add
label define statefip_lbl 99 `"State not identified"', add
label values statefip statefip_lbl

label define asecflag_lbl 1 `"ASEC"'
label define asecflag_lbl 2 `"March Basic"', add
label values asecflag asecflag_lbl

label define month_lbl 01 `"January"'
label define month_lbl 02 `"February"', add
label define month_lbl 03 `"March"', add
label define month_lbl 04 `"April"', add
label define month_lbl 05 `"May"', add
label define month_lbl 06 `"June"', add
label define month_lbl 07 `"July"', add
label define month_lbl 08 `"August"', add
label define month_lbl 09 `"September"', add
label define month_lbl 10 `"October"', add
label define month_lbl 11 `"November"', add
label define month_lbl 12 `"December"', add
label values month month_lbl

label define nchild_lbl 0 `"0 children present"'
label define nchild_lbl 1 `"1 child present"', add
label define nchild_lbl 2 `"2"', add
label define nchild_lbl 3 `"3"', add
label define nchild_lbl 4 `"4"', add
label define nchild_lbl 5 `"5"', add
label define nchild_lbl 6 `"6"', add
label define nchild_lbl 7 `"7"', add
label define nchild_lbl 8 `"8"', add
label define nchild_lbl 9 `"9+"', add
label values nchild nchild_lbl

label define relate_lbl 0101 `"Head/householder"'
label define relate_lbl 0201 `"Spouse"', add
label define relate_lbl 0301 `"Child"', add
label define relate_lbl 0303 `"Stepchild"', add
label define relate_lbl 0501 `"Parent"', add
label define relate_lbl 0701 `"Sibling"', add
label define relate_lbl 0901 `"Grandchild"', add
label define relate_lbl 1001 `"Other relatives, n.s."', add
label define relate_lbl 1113 `"Partner/roommate"', add
label define relate_lbl 1114 `"Unmarried partner"', add
label define relate_lbl 1115 `"Housemate/roomate"', add
label define relate_lbl 1241 `"Roomer/boarder/lodger"', add
label define relate_lbl 1242 `"Foster children"', add
label define relate_lbl 1260 `"Other nonrelatives"', add
label define relate_lbl 9100 `"Armed Forces, relationship unknown"', add
label define relate_lbl 9200 `"Age under 14, relationship unknown"', add
label define relate_lbl 9900 `"Relationship unknown"', add
label define relate_lbl 9999 `"9999"', add
label values relate relate_lbl

label define age_lbl 00 `"Under 1 year"'
label define age_lbl 01 `"1"', add
label define age_lbl 02 `"2"', add
label define age_lbl 03 `"3"', add
label define age_lbl 04 `"4"', add
label define age_lbl 05 `"5"', add
label define age_lbl 06 `"6"', add
label define age_lbl 07 `"7"', add
label define age_lbl 08 `"8"', add
label define age_lbl 09 `"9"', add
label define age_lbl 10 `"10"', add
label define age_lbl 11 `"11"', add
label define age_lbl 12 `"12"', add
label define age_lbl 13 `"13"', add
label define age_lbl 14 `"14"', add
label define age_lbl 15 `"15"', add
label define age_lbl 16 `"16"', add
label define age_lbl 17 `"17"', add
label define age_lbl 18 `"18"', add
label define age_lbl 19 `"19"', add
label define age_lbl 20 `"20"', add
label define age_lbl 21 `"21"', add
label define age_lbl 22 `"22"', add
label define age_lbl 23 `"23"', add
label define age_lbl 24 `"24"', add
label define age_lbl 25 `"25"', add
label define age_lbl 26 `"26"', add
label define age_lbl 27 `"27"', add
label define age_lbl 28 `"28"', add
label define age_lbl 29 `"29"', add
label define age_lbl 30 `"30"', add
label define age_lbl 31 `"31"', add
label define age_lbl 32 `"32"', add
label define age_lbl 33 `"33"', add
label define age_lbl 34 `"34"', add
label define age_lbl 35 `"35"', add
label define age_lbl 36 `"36"', add
label define age_lbl 37 `"37"', add
label define age_lbl 38 `"38"', add
label define age_lbl 39 `"39"', add
label define age_lbl 40 `"40"', add
label define age_lbl 41 `"41"', add
label define age_lbl 42 `"42"', add
label define age_lbl 43 `"43"', add
label define age_lbl 44 `"44"', add
label define age_lbl 45 `"45"', add
label define age_lbl 46 `"46"', add
label define age_lbl 47 `"47"', add
label define age_lbl 48 `"48"', add
label define age_lbl 49 `"49"', add
label define age_lbl 50 `"50"', add
label define age_lbl 51 `"51"', add
label define age_lbl 52 `"52"', add
label define age_lbl 53 `"53"', add
label define age_lbl 54 `"54"', add
label define age_lbl 55 `"55"', add
label define age_lbl 56 `"56"', add
label define age_lbl 57 `"57"', add
label define age_lbl 58 `"58"', add
label define age_lbl 59 `"59"', add
label define age_lbl 60 `"60"', add
label define age_lbl 61 `"61"', add
label define age_lbl 62 `"62"', add
label define age_lbl 63 `"63"', add
label define age_lbl 64 `"64"', add
label define age_lbl 65 `"65"', add
label define age_lbl 66 `"66"', add
label define age_lbl 67 `"67"', add
label define age_lbl 68 `"68"', add
label define age_lbl 69 `"69"', add
label define age_lbl 70 `"70"', add
label define age_lbl 71 `"71"', add
label define age_lbl 72 `"72"', add
label define age_lbl 73 `"73"', add
label define age_lbl 74 `"74"', add
label define age_lbl 75 `"75"', add
label define age_lbl 76 `"76"', add
label define age_lbl 77 `"77"', add
label define age_lbl 78 `"78"', add
label define age_lbl 79 `"79"', add
label define age_lbl 80 `"80"', add
label define age_lbl 81 `"81"', add
label define age_lbl 82 `"82"', add
label define age_lbl 83 `"83"', add
label define age_lbl 84 `"84"', add
label define age_lbl 85 `"85"', add
label define age_lbl 86 `"86"', add
label define age_lbl 87 `"87"', add
label define age_lbl 88 `"88"', add
label define age_lbl 89 `"89"', add
label define age_lbl 90 `"90 (90+, 1988-2002)"', add
label define age_lbl 91 `"91"', add
label define age_lbl 92 `"92"', add
label define age_lbl 93 `"93"', add
label define age_lbl 94 `"94"', add
label define age_lbl 95 `"95"', add
label define age_lbl 96 `"96"', add
label define age_lbl 97 `"97"', add
label define age_lbl 98 `"98"', add
label define age_lbl 99 `"99+"', add
label values age age_lbl

label define sex_lbl 1 `"Male"'
label define sex_lbl 2 `"Female"', add
label define sex_lbl 9 `"NIU"', add
label values sex sex_lbl

label define race_lbl 100 `"White"'
label define race_lbl 200 `"Black/Negro"', add
label define race_lbl 300 `"American Indian/Aleut/Eskimo"', add
label define race_lbl 650 `"Asian or Pacific Islander"', add
label define race_lbl 651 `"Asian only"', add
label define race_lbl 652 `"Hawaiian/Pacific Islander only"', add
label define race_lbl 700 `"Other (single) race, n.e.c."', add
label define race_lbl 801 `"White-Black"', add
label define race_lbl 802 `"White-American Indian"', add
label define race_lbl 803 `"White-Asian"', add
label define race_lbl 804 `"White-Hawaiian/Pacific Islander"', add
label define race_lbl 805 `"Black-American Indian"', add
label define race_lbl 806 `"Black-Asian"', add
label define race_lbl 807 `"Black-Hawaiian/Pacific Islander"', add
label define race_lbl 808 `"American Indian-Asian"', add
label define race_lbl 809 `"Asian-Hawaiian/Pacific Islander"', add
label define race_lbl 810 `"White-Black-American Indian"', add
label define race_lbl 811 `"White-Black-Asian"', add
label define race_lbl 812 `"White-American Indian-Asian"', add
label define race_lbl 813 `"White-Asian-Hawaiian/Pacific Islander"', add
label define race_lbl 814 `"White-Black-American Indian-Asian"', add
label define race_lbl 815 `"American Indian-Hawaiian/Pacific Islander"', add
label define race_lbl 816 `"White-Black--Hawaiian/Pacific Islander"', add
label define race_lbl 817 `"White-American Indian-Hawaiian/Pacific Islander"', add
label define race_lbl 818 `"Black-American Indian-Asian"', add
label define race_lbl 819 `"White-American Indian-Asian-Hawaiian/Pacific Islander"', add
label define race_lbl 820 `"Two or three races, unspecified"', add
label define race_lbl 830 `"Four or five races, unspecified"', add
label define race_lbl 999 `"NIU"', add
label values race race_lbl

label define marst_lbl 1 `"Married, spouse present"'
label define marst_lbl 2 `"Married, spouse absent"', add
label define marst_lbl 3 `"Separated"', add
label define marst_lbl 4 `"Divorced"', add
label define marst_lbl 5 `"Widowed"', add
label define marst_lbl 6 `"Never married/single"', add
label define marst_lbl 7 `"Widowed or Divorced"', add
label define marst_lbl 9 `"Unknown"', add
label values marst marst_lbl

label define educ99_lbl 00 `"NIU"'
label define educ99_lbl 01 `"No school completed"', add
label define educ99_lbl 04 `"1st-4th grade"', add
label define educ99_lbl 05 `"5th-8th grade"', add
label define educ99_lbl 06 `"9th grade"', add
label define educ99_lbl 07 `"10th grade"', add
label define educ99_lbl 08 `"11th grade"', add
label define educ99_lbl 09 `"12th grade, no diploma"', add
label define educ99_lbl 10 `"High school graduate, or GED"', add
label define educ99_lbl 11 `"Some college, no degree"', add
label define educ99_lbl 12 `"Associate degree, type of program not specified"', add
label define educ99_lbl 13 `"Associate degree, occupational program"', add
label define educ99_lbl 14 `"Associate degree, academic program"', add
label define educ99_lbl 15 `"Bachelors degree"', add
label define educ99_lbl 16 `"Masters degree"', add
label define educ99_lbl 17 `"Professional degree"', add
label define educ99_lbl 18 `"Doctorate degree"', add
label values educ99 educ99_lbl

label define wkswork2_lbl 0 `"NIU"'
label define wkswork2_lbl 1 `"1-13 weeks"', add
label define wkswork2_lbl 2 `"14-26 weeks"', add
label define wkswork2_lbl 3 `"27-39 weeks"', add
label define wkswork2_lbl 4 `"40-47 weeks"', add
label define wkswork2_lbl 5 `"48-49 weeks"', add
label define wkswork2_lbl 6 `"50-52 weeks"', add
label define wkswork2_lbl 9 `"Missing data"', add
label values wkswork2 wkswork2_lbl

label define wksunem2_lbl 0 `"None"'
label define wksunem2_lbl 1 `"1-4 weeks"', add
label define wksunem2_lbl 2 `"5-10 weeks"', add
label define wksunem2_lbl 3 `"11-14 weeks"', add
label define wksunem2_lbl 4 `"15-26 weeks"', add
label define wksunem2_lbl 5 `"27-39 weeks"', add
label define wksunem2_lbl 6 `"40+ weeks"', add
label define wksunem2_lbl 7 `"Over 26 weeks (1962-1967)"', add
label define wksunem2_lbl 8 `"Missing/Unknown"', add
label define wksunem2_lbl 9 `"NIU"', add
label values wksunem2 wksunem2_lbl

label define nwlookwk_lbl 00 `"Did not look for work/wasn't on layoff"'
label define nwlookwk_lbl 01 `"1 week"', add
label define nwlookwk_lbl 02 `"2 weeks"', add
label define nwlookwk_lbl 03 `"3 weeks"', add
label define nwlookwk_lbl 04 `"4 weeks"', add
label define nwlookwk_lbl 05 `"5 weeks"', add
label define nwlookwk_lbl 06 `"6 weeks"', add
label define nwlookwk_lbl 07 `"7 weeks"', add
label define nwlookwk_lbl 08 `"8 weeks"', add
label define nwlookwk_lbl 09 `"9 weeks"', add
label define nwlookwk_lbl 10 `"10 weeks"', add
label define nwlookwk_lbl 11 `"11 weeks"', add
label define nwlookwk_lbl 12 `"12 weeks"', add
label define nwlookwk_lbl 13 `"13 weeks"', add
label define nwlookwk_lbl 14 `"14 weeks"', add
label define nwlookwk_lbl 15 `"15 weeks"', add
label define nwlookwk_lbl 16 `"16 weeks"', add
label define nwlookwk_lbl 17 `"17 weeks"', add
label define nwlookwk_lbl 18 `"18 weeks"', add
label define nwlookwk_lbl 19 `"19 weeks"', add
label define nwlookwk_lbl 20 `"20 weeks"', add
label define nwlookwk_lbl 21 `"21 weeks"', add
label define nwlookwk_lbl 22 `"22 weeks"', add
label define nwlookwk_lbl 23 `"23 weeks"', add
label define nwlookwk_lbl 24 `"24 weeks"', add
label define nwlookwk_lbl 25 `"25 weeks"', add
label define nwlookwk_lbl 26 `"26 weeks"', add
label define nwlookwk_lbl 27 `"27 weeks"', add
label define nwlookwk_lbl 28 `"28 weeks"', add
label define nwlookwk_lbl 29 `"29 weeks"', add
label define nwlookwk_lbl 30 `"30 weeks"', add
label define nwlookwk_lbl 31 `"31 weeks"', add
label define nwlookwk_lbl 32 `"32 weeks"', add
label define nwlookwk_lbl 33 `"33 weeks"', add
label define nwlookwk_lbl 34 `"34 weeks"', add
label define nwlookwk_lbl 35 `"35 weeks"', add
label define nwlookwk_lbl 36 `"36 weeks"', add
label define nwlookwk_lbl 37 `"37 weeks"', add
label define nwlookwk_lbl 38 `"38 weeks"', add
label define nwlookwk_lbl 39 `"39 weeks"', add
label define nwlookwk_lbl 40 `"40 weeks"', add
label define nwlookwk_lbl 41 `"41 weeks"', add
label define nwlookwk_lbl 42 `"42 weeks"', add
label define nwlookwk_lbl 43 `"43 weeks"', add
label define nwlookwk_lbl 44 `"44 weeks"', add
label define nwlookwk_lbl 45 `"45 weeks"', add
label define nwlookwk_lbl 46 `"46 weeks"', add
label define nwlookwk_lbl 47 `"47 weeks"', add
label define nwlookwk_lbl 48 `"48 weeks"', add
label define nwlookwk_lbl 49 `"49 weeks"', add
label define nwlookwk_lbl 50 `"50 weeks"', add
label define nwlookwk_lbl 51 `"51 weeks"', add
label define nwlookwk_lbl 52 `"52 weeks"', add
label define nwlookwk_lbl 99 `"NIU"', add
label values nwlookwk nwlookwk_lbl

label define paidhour_lbl 0 `"NIU"'
label define paidhour_lbl 1 `"No"', add
label define paidhour_lbl 2 `"Yes"', add
label define paidhour_lbl 6 `"Refused"', add
label define paidhour_lbl 7 `"Don't Know"', add
label values paidhour paidhour_lbl

label define filestat_lbl 0 `"No data"'
label define filestat_lbl 1 `"Joint, both less than 65"', add
label define filestat_lbl 2 `"Joint, one less than 65, one 65+"', add
label define filestat_lbl 3 `"Joint, both 65+"', add
label define filestat_lbl 4 `"Head of household"', add
label define filestat_lbl 5 `"Single"', add
label define filestat_lbl 6 `"Nonfiler"', add
label values filestat filestat_lbl

label define caid_lbl 1 `"No"'
label define caid_lbl 2 `"Yes"', add
label values caid caid_lbl

label define schip_lbl 0 `"NIU"'
label define schip_lbl 1 `"No"', add
label define schip_lbl 2 `"Yes"', add
label values schip schip_lbl

label define ftype_lbl 1 `"Primary family"'
label define ftype_lbl 2 `"Nonfamily householder"', add
label define ftype_lbl 3 `"Related subfamily"', add
label define ftype_lbl 4 `"Unrelated subfamily"', add
label define ftype_lbl 5 `"Secondary individual"', add
label define ftype_lbl 9 `"Missing"', add
label values ftype ftype_lbl





// RESTRICT TO DESIRED POPULATION
keep if ftotval > 0
keep if year == 2010


// REPLACE MISSING VALUES

replace fedtaxac = . if fedtaxac == 999999
replace statax = . if statax == 999999
replace incwelfr = . if incwelfr == 99999
replace hourwage = . if abs(hourwage - 99.99) < .0001
replace inctot = . if inlist(inctot,99999999,99999998)
replace incwage = . if incwage == 9999999
replace incbus = . if inlist(incbus,9999999,9999998)
replace fica = . if fica == 99999
replace paidhour = . if !inlist(paidhour,1,2)
replace paidhour = paidhour - 1
replace eitcred = . if eitcred == 9999
replace numemps = . if numemps == 0
replace taxinc = . if taxinc == 99997
replace nwlookwk = . if nwlookwk == 99
replace wksunem1 = . if wksunem1 == 99
replace wksunem2 = . if wksunem2 > 7


egen inccat = cut(inctot), group(10)
egen hrscat = cut(hrswork), group(10)

gen male = sex == "Male":sex_lbl
gen incthou = incwage/1000
gen incshare = incwage/ftotval
gen tothrs = uhrswork*wkswork1

gen netinc = ftotval - fedtaxac - stataxac - fica + stampval
gen nettax = ftotval - netinc
gen nettrans = -nettax

gen mktinc = ftotval - incwelfr



// IMPORT MARGINAL TAX RATES FROM NBER TAXSIM
drop statefip

gen mstat = .
replace mstat = 2 if inlist(filestat,1,2,3)
replace mstat = 3 if filestat==4
replace mstat = 1 if filestat==1

gen agex = 0
replace agex = 1 if filestat==2
replace agex = 2 if filestat==3

gen depx = nchild
replace depx = 1 if depx == 0 & mstat == 3
gen pwages = incwage
gen depchild = depx


taxsim9, replace
save $dropbox/data/intermediate/cpsdata_taxsim.dta, replace

gen mtr = (frate + srate + ficar)*0.01


// CONVERT NOMINAL TO REAL
foreach var of varlist ftotval netinc nettax nettrans {
	replace `var' = `var'*cpi99
}


// GENERATE SMOOTHED INCOME GRID FOR KERNEL REGRESSIONS
gen rawgrid = _n/50 in 1/1000
gen incgrid = exp(rawgrid)

local bwbig 5000
local bwsm 2000

lpoly mtr mktinc, bw(`bwbig') nograph at(incgrid) gen(mtrpoly)
lpoly mtr mktinc if nchild == 2, bw(`bwsm') nograph at(incgrid) gen(mtrpoly2ch)
kdensity mktinc, bw(`bwbig') at(incgrid) gen(incdens) nograph

gen benefits = stampval + incwelfr
lpoly benefits mktinc, bw(`bwbig') nograph at(incgrid) gen(benpoly)
lpoly benefits mktinc if nchild == 2, bw(`bwsm') nograph at(incgrid) gen(benpoly2ch)
gen benmtr = (benpoly - benpoly[_n-1])/(incgrid - incgrid[_n-1])
gen benmtr2ch = (benpoly2ch - benpoly2ch[_n-1])/(incgrid - incgrid[_n-1])

gen fulltime = tothrs >= 2080
lpoly fulltime mktinc if tothrs > 0, bw(`bwbig') nograph at(incgrid) gen(fulltimepoly)

keep if !missing(incgrid) // for speed exporting
lpoly benmtr incgrid, bw(`bwbig') nograph at(incgrid) gen(benmtrpoly)
lpoly benmtr2ch incgrid, bw(`bwsm') nograph at(incgrid) gen(benmtr2chpoly)

gen netmtr = mtrpoly - benmtrpoly
gen netmtr2ch = mtrpoly2ch - benmtr2chpoly

export delim incgrid netmtr netmtr2ch incdens fulltimepoly using "$dropbox/data/intermediate/cpsdata.csv", replace
